==> k3d-2.13.0.tar.gz: k3d-2.13.0/k3d/colormaps/basic_color_maps.py <==
CoolWarm = [
    0, 0.23137254902, 0.298039215686, 0.752941176471,
    0.5, 0.865, 0.865, 0.865,
    1, 0.705882352941, 0.0156862745098, 0.149019607843
]

WarmCool = [
    0, 0.705882352941, 0.0156862745098, 0.149019607843,
    0.5, 0.865, 0.865, 0.865,
    1, 0.23137254902, 0.298039215686, 0.752941176471
]

Rainbow = [
    0, 0, 0, 1,
    0.25, 0, 1, 1,
    0.5, 0, 1, 0,
    0.75, 1, 1, 0,
    1.0, 1, 0, 0
]

RainbowDesaturated = [
    0, 0.278431372549, 0.278431372549, 0.858823529412,
    0.143, 0, 0, 0.360784313725,
    0.285, 0, 1, 1,
    0.429, 0, 0.501960784314, 0,
    0.571, 1, 1, 0,
    0.714, 1, 0.380392156863, 0,
    0.857, 0.419607843137, 0, 0,
    1, 0.8784313725489999, 0.301960784314, 0.301960784314
]

BlackBodyRadiation = [
    0, 0, 0, 0,
    0.4, 0.901960784314, 0, 0,
    0.8, 0.901960784314, 0.901960784314, 0,
    1, 1, 1, 1
]

Binary = [
    0, 1, 1, 1,
    1, 0, 0, 0
]

Jet = [
    -1, 0, 0, 0.5625,
    -0.77777799999999997, 0, 0, 1,
    -0.269841, 0, 1, 1,
    -0.015873000000000002, 0.5, 1, 0.5,
    0.238095, 1, 1, 0,
    0.74603200000000003, 1, 0, 0,
    1, 0.5, 0, 0
]

Gold = [
    0, 0, 0, 0,
    0.13, 0.19, 0.03, 0,
    0.25, 0.39, 0.12, 0,
    0.38, 0.59, 0.26, 0,
    0.50, 0.80, 0.46, 0.08,
    0.63, 0.99, 0.71, 0.21,
    0.75, 0.99, 0.88, 0.34,
    0.88, 0.99, 0.99, 0.48,
    1, 0.90, 0.95, 0.61
]

Reds = [
    0, 0.75, 0, 0,
    0.5, 1, 0.5, 0,
    0.95, 1, 1, 0,
    1, 1, 1, 1
]

Greens = [
    0, 0, 0.75, 0,
    0.5, 0.5, 1, 0,
    0.95, 1, 1, 0,
    1, 1, 1, 1
]

Blues = [
    0, 0, 0, 1,
    0.5, 0, 0.5, 1,
    0.95, 0, 1, 1,
    1, 1, 1, 1
]

==> k3d-2.15.1.tar.gz: k3d-2.15.1/k3d/colormaps/basic_color_maps.py <==
"""Selection of basic colormaps from matplotlib and Paraview.

Contains :

- CoolWarm
- WarmCool
- Rainbow
- RainbowDesaturated
- BlackBodyRadiation
- Binary
- Jet
- Golds
- Reds
- Blues
- Greens
"""

CoolWarm = [
    0, 0.23137254902, 0.298039215686, 0.752941176471,
    0.5, 0.865, 0.865, 0.865,
    1, 0.705882352941, 0.0156862745098, 0.149019607843
]

WarmCool = [
    0, 0.705882352941, 0.0156862745098, 0.149019607843,
    0.5, 0.865, 0.865, 0.865,
    1, 0.23137254902, 0.298039215686, 0.752941176471
]

Rainbow = [
    0, 0, 0, 1,
    0.25, 0, 1, 1,
    0.5, 0, 1, 0,
    0.75, 1, 1, 0,
    1.0, 1, 0, 0
]

RainbowDesaturated = [
    0, 0.278431372549, 0.278431372549, 0.858823529412,
    0.143, 0, 0, 0.360784313725,
    0.285, 0, 1, 1,
    0.429, 0, 0.501960784314, 0,
    0.571, 1, 1, 0,
    0.714, 1, 0.380392156863, 0,
    0.857, 0.419607843137, 0, 0,
    1, 0.8784313725489999, 0.301960784314, 0.301960784314
]

BlackBodyRadiation = [
    0, 0, 0, 0,
    0.4, 0.901960784314, 0, 0,
    0.8, 0.901960784314, 0.901960784314, 0,
    1, 1, 1, 1
]

Binary = [
    0, 1, 1, 1,
    1, 0, 0, 0
]

Jet = [
    -1, 0, 0, 0.5625,
    -0.77777799999999997, 0, 0, 1,
    -0.269841, 0, 1, 1,
    -0.015873000000000002, 0.5, 1, 0.5,
    0.238095, 1, 1, 0,
    0.74603200000000003, 1, 0, 0,
    1, 0.5, 0, 0
]

Gold = [
    0, 0, 0, 0,
    0.13, 0.19, 0.03, 0,
    0.25, 0.39, 0.12, 0,
    0.38, 0.59, 0.26, 0,
    0.50, 0.80, 0.46, 0.08,
    0.63, 0.99, 0.71, 0.21,
    0.75, 0.99, 0.88, 0.34,
    0.88, 0.99, 0.99, 0.48,
    1, 0.90, 0.95, 0.61
]

Reds = [
    0, 0.75, 0, 0,
    0.5, 1, 0.5, 0,
    0.95, 1, 1, 0,
    1, 1, 1, 1
]

Greens = [
    0, 0, 0.75, 0,
    0.5, 0.5, 1, 0,
    0.95, 1, 1, 0,
    1, 1, 1, 1
]

Blues = [
    0, 0, 0, 1,
    0.5, 0, 0.5, 1,
    0.95, 0, 1, 1,
    1, 1, 1, 1
]
